Common buttons

Yleiset napit | Sisällysluettelo

Alla on lyhyt selostus kaikista toimintonapeista.

| Lihavointi.
| Kursivointi.
| Alleviivaus.
| Yliviivaus.
| vasen tasaus.
| Keskitys.
| Oikea tasaus.
| Pakotettu tasaus.
| Järjestämätön lista.
| Järjestetty lista/numeroitu lista
| Poista / vähennä sisennystä.
| Sisennä.
| Peruuta viimeinen muutos.
| Tee uudelleen viimeinen peruutettu muutos.
| Lisää linkki. Lisätietoa tästä toiminnosta lisää linkki -osiosta.
| Poista linkki valitusta tekstistä.
| Lisää kuva. Lue lisää tästä toiminnosta lisää kuva -osiosta.
| Siisti koodi. Tämä toiminto on käytännöllinen kun liität tekstiä toimistosovelluksista.
| Näyttäää tämän apuikkunan.
| Avaa HTML lähdekoodieditorin.
| Lisää tualu. Lue lisää tästä toiminnosta lisää taulu -osiosta.
| Lisää rivi valitun rivin edelle.
| Lisää rivi valitun rivin jälkeen.
| Poista valittu rivi.
| Lisää saraka valitun sarakkeen jälkeen.
| Lisää sarake valitun sarakkeen edelle.
| Poistaa valitun sarakkeen.
| Lisää vaakaviiva.
| Poista muotoilu valitusta tekstistä.
| Tekee valitusta tekstistä alamääreistä.
| Tekee valitusta tekstistä ylämääreistä.

Mene: Sisällysluetteloon | Alkuun